@@ -41,7 +41,7 @@
 #include <libxfdashboard/window-content.h>
 #include <libxfdashboard/image-content.h>
 #include <libxfdashboard/stylable.h>
-#include <libxfdashboard/application.h>
+#include <libxfdashboard/core.h>
 #include <libxfdashboard/compat.h>
 
 
@@ -1146,7 +1146,7 @@ static void xfdashboard_live_window_init(XfdashboardLiveWindow *self)
 	clutter_actor_set_reactive(CLUTTER_ACTOR(self), TRUE);
 
 	/* Set default values */
-	priv->windowTracker=xfdashboard_window_tracker_get_default();
+	priv->windowTracker=xfdashboard_core_get_window_tracker(NULL);
 	priv->windowNumber=0;
 	priv->paddingTitle=0.0f;
 	priv->paddingClose=0.0f;
@@ -1188,7 +1188,7 @@ static void xfdashboard_live_window_init(XfdashboardLiveWindow *self)
 	clutter_actor_add_child(priv->actorControlLayer, priv->actorWindowNumber);
 
 	/* Bind to settings to react on changes */
-	settings=xfdashboard_application_get_settings(NULL);
+	settings=xfdashboard_core_get_settings(NULL);
 	priv->settingsAllowSubwindowsBinding=
 		g_object_bind_property(settings,
 								"allow-subwindows",
