@@ -41,7 +41,7 @@
 struct _XfdashboardOutlineEffectPrivate
 {
 	/* Properties related */
-	XfdashboardGradientColor		*color;
+	XfdashboardGradientColor	*color;
 	gfloat						width;
 	XfdashboardBorders			borders;
 	XfdashboardCorners			corners;
@@ -95,7 +95,7 @@ static void _xfdashboard_outline_effect_invalidate(XfdashboardOutlineEffect *sel
 	}
 }
 
-/* Draw outline with gradient */
+/* Draw a single outline with current cairo context (line width, pattern etc.) */
 static void _xfdashboard_outline_effect_draw_outline_intern(XfdashboardOutlineEffect *self,
 															cairo_t *inContext,
 															gint inWidth,
@@ -121,9 +121,9 @@ static void _xfdashboard_outline_effect_draw_outline_intern(XfdashboardOutlineEf
 	if(priv->drawRadius>0.0f)
 	{
 		/* Top-left corner */
-		if(priv->corners & XFDASHBOARD_CORNERS_TOP_LEFT &&
-			priv->borders & XFDASHBOARD_BORDERS_LEFT &&
-			priv->borders & XFDASHBOARD_BORDERS_TOP)
+		if((priv->corners & XFDASHBOARD_CORNERS_TOP_LEFT) &&
+			(priv->borders & XFDASHBOARD_BORDERS_LEFT) &&
+			(priv->borders & XFDASHBOARD_BORDERS_TOP))
 		{
 			cairo_arc(inContext,
 						priv->drawRadius+penOffset, priv->drawRadius+penOffset,
@@ -147,9 +147,9 @@ static void _xfdashboard_outline_effect_draw_outline_intern(XfdashboardOutlineEf
 		}
 
 		/* Top-right corner */
-		if(priv->corners & XFDASHBOARD_CORNERS_TOP_RIGHT &&
-			priv->borders & XFDASHBOARD_BORDERS_TOP &&
-			priv->borders & XFDASHBOARD_BORDERS_RIGHT)
+		if((priv->corners & XFDASHBOARD_CORNERS_TOP_RIGHT) &&
+			(priv->borders & XFDASHBOARD_BORDERS_TOP) &&
+			(priv->borders & XFDASHBOARD_BORDERS_RIGHT))
 		{
 			cairo_arc(inContext,
 						inWidth-priv->drawRadius-penOffset, priv->drawRadius+penOffset,
@@ -174,9 +174,9 @@ static void _xfdashboard_outline_effect_draw_outline_intern(XfdashboardOutlineEf
 		}
 
 		/* Bottom-right corner */
-		if(priv->corners & XFDASHBOARD_CORNERS_BOTTOM_RIGHT &&
-			priv->borders & XFDASHBOARD_BORDERS_RIGHT &&
-			priv->borders & XFDASHBOARD_BORDERS_BOTTOM)
+		if((priv->corners & XFDASHBOARD_CORNERS_BOTTOM_RIGHT) &&
+			(priv->borders & XFDASHBOARD_BORDERS_RIGHT) &&
+			(priv->borders & XFDASHBOARD_BORDERS_BOTTOM))
 		{
 			cairo_arc(inContext,
 						inWidth-priv->drawRadius-penOffset, inHeight-priv->drawRadius-penOffset,
@@ -200,9 +200,9 @@ static void _xfdashboard_outline_effect_draw_outline_intern(XfdashboardOutlineEf
 		}
 
 		/* Bottom-left corner */
-		if(priv->corners & XFDASHBOARD_CORNERS_BOTTOM_LEFT &&
-			priv->borders & XFDASHBOARD_BORDERS_BOTTOM &&
-			priv->borders & XFDASHBOARD_BORDERS_LEFT)
+		if((priv->corners & XFDASHBOARD_CORNERS_BOTTOM_LEFT) &&
+			(priv->borders & XFDASHBOARD_BORDERS_BOTTOM) &&
+			(priv->borders & XFDASHBOARD_BORDERS_LEFT))
 		{
 			cairo_arc(inContext,
 						priv->drawRadius+penOffset, inHeight-priv->drawRadius-penOffset,
@@ -262,10 +262,11 @@ static void _xfdashboard_outline_effect_draw_outline_intern(XfdashboardOutlineEf
 		}
 }
 
-static void _xfdashboard_outline_effect_draw_outline_gradient(XfdashboardOutlineEffect *self,
-																cairo_t *inContext,
-																gint inWidth,
-																gint inHeight)
+/* More complex drawing outline function for path gradient colors */
+static void _xfdashboard_outline_effect_draw_outline_path_gradient(XfdashboardOutlineEffect *self,
+																	cairo_t *inContext,
+																	gint inWidth,
+																	gint inHeight)
 {
 	XfdashboardOutlineEffectPrivate		*priv;
 	ClutterColor						progressColor;
@@ -318,13 +319,195 @@ static void _xfdashboard_outline_effect_draw_outline_gradient(XfdashboardOutline
 	_xfdashboard_outline_effect_draw_outline_intern(self, inContext, inWidth, inHeight, priv->drawLineWidth, TRUE);
 }
 
-/* Draw outline in a single color */
-static void _xfdashboard_outline_effect_draw_outline_solid(XfdashboardOutlineEffect *self,
+/* Create pattern for simple outline drawing function */
+static cairo_pattern_t* _xfdashboard_outline_effect_create_pattern(XfdashboardOutlineEffect *self,
+																	cairo_t *inContext,
+																	int inWidth,
+																	int inHeight)
+{
+	XfdashboardOutlineEffectPrivate		*priv;
+	XfdashboardGradientType				type;
+	cairo_pattern_t						*pattern;
+
+	g_return_val_if_fail(XFDASHBOARD_IS_OUTLINE_EFFECT(self), NULL);
+
+	priv=self->priv;
+	pattern=NULL;
+
+	/* Get type of gradient to create pattern for */
+	type=xfdashboard_gradient_color_get_gradient_type(priv->color);
+
+	/* Create solid pattern if gradient is solid type */
+	if(type==XFDASHBOARD_GRADIENT_TYPE_SOLID)
+	{
+		const ClutterColor				*color;
+
+		color=xfdashboard_gradient_color_get_solid_color(priv->color);
+		pattern=cairo_pattern_create_rgba(CLAMP(color->red / 255.0, 0.0, 1.0),
+											CLAMP(color->green / 255.0, 0.0, 1.0),
+											CLAMP(color->blue / 255.0, 0.0, 1.0),
+											CLAMP(color->alpha / 255.0, 0.0, 1.0));
+	}
+
+	/* Create linear gradient pattern if gradient is linear */
+	if(type==XFDASHBOARD_GRADIENT_TYPE_LINEAR_GRADIENT)
+	{
+		gdouble						width, height;
+		gdouble						midX, midY;
+		gdouble						startX, startY;
+		gdouble						endX, endY;
+		gdouble						angle;
+		gdouble						atanRectangle;
+		gdouble						tanAngle;
+		guint						i, stops;
+
+		/* Adjust angle to find region */
+		angle=(2*M_PI)-xfdashboard_gradient_color_get_angle(priv->color);
+		while(angle<-M_PI) angle+=(2*M_PI);
+		while(angle>M_PI) angle-=(2*M_PI);
+
+		/* I do not know why but exactly at radians of 0.0 and M_PI the
+		 * start and end points are mirrored so this is a dirty workaround
+		 * to swap angles. Maybe it is because tan(angle) resolves to -0.0
+		 * instead of 0.0. Looks like a sign error.
+		 */
+		if(angle==0.0) angle=M_PI;
+			else if(angle==M_PI) angle=0.0;
+
+		/* Get size of region */
+		width=inWidth;
+		height=inHeight;
+
+		/* Find region and calculates points */
+		atanRectangle=atan2(height, width);
+		tanAngle=tan(angle);
+
+		midX=(width/2.0);
+		midY=(height/2.0);
+
+		if(angle!=0.0 && (angle>-atanRectangle) && (angle<=atanRectangle))
+		{
+			/* Region 1 */
+			startX=midX+(width/2.0);
+			startY=midY-((width/2.0)*tanAngle);
+
+			endX=midX-(width/2.0);
+			endY=midY+((width/2.0)*tanAngle);
+		}
+			else if((angle>atanRectangle) && (angle<=(M_PI-atanRectangle)))
+			{
+				/* Region 2 */
+				startX=midX+(height/(2.0*tanAngle));
+				startY=midY-(height/2.0);
+
+				endX=midX-(height/(2.0*tanAngle));
+				endY=midY+(height/2.0);
+			}
+			else if(angle==0.0 || (angle>(M_PI-atanRectangle)) || (angle<=-(M_PI-atanRectangle)))
+			{
+				/* Region 3 */
+				startX=midX-(width/2.0);
+				startY=midY+((width/2.0)*tanAngle);
+
+				endX=midX+(width/2.0);
+				endY=midY-((width/2.0)*tanAngle);
+			}
+			else
+			{
+				/* Region 4 */
+				startX=midX-(height/(2.0*tanAngle));
+				startY=midY+(height/2.0);
+
+				endX=midX+(height/(2.0*tanAngle));
+				endY=midY-(height/2.0);
+			}
+
+		/* Reduce full length to requested length if gradient should be repeated */
+		if(xfdashboard_gradient_color_get_repeat(priv->color))
+		{
+			gdouble					vectorX, vectorY;
+			gdouble					distance;
+			gdouble					requestedLength;
+
+			/* Calculate distance between start and end point as this is the current
+			 * length of pattern.
+			 */
+			vectorX=endX-startX;
+			vectorY=endY-startY;
+			distance=sqrt((vectorX*vectorX) + (vectorY*vectorY));
+
+			/* Reduce distance by percentage or absolute length */
+			requestedLength=xfdashboard_gradient_color_get_length(priv->color);
+			if(requestedLength<0.0)
+			{
+				vectorX*=-requestedLength;
+				vectorY*=-requestedLength;
+			}
+				else
+				{
+					vectorX=(vectorX/distance)*requestedLength;
+					vectorY=(vectorY/distance)*requestedLength;
+				}
+
+			endX=startX+vectorX;
+			endY=startY+vectorY;
+		}
+
+		/* Create pattern based on calculated points */
+		pattern=cairo_pattern_create_linear(startX, startY, endX, endY);
+
+		stops=xfdashboard_gradient_color_get_number_stops(priv->color);
+		for(i=0; i<stops; i++)
+		{
+			gdouble					offset;
+			ClutterColor			color;
+
+			xfdashboard_gradient_color_get_stop(priv->color, i, &offset, &color);
+			cairo_pattern_add_color_stop_rgba(pattern,
+												offset,
+												CLAMP(color.red / 255.0, 0.0, 1.0),
+												CLAMP(color.green / 255.0, 0.0, 1.0),
+												CLAMP(color.blue / 255.0, 0.0, 1.0),
+												CLAMP(color.alpha / 255.0, 0.0, 1.0));
+		}
+
+		cairo_pattern_set_extend(pattern, xfdashboard_gradient_color_get_repeat(priv->color) ? CAIRO_EXTEND_REPEAT : CAIRO_EXTEND_PAD);
+	}
+
+	/* Create solid pattern if gradient is a path gradient as this should only
+	 * happen if using the complex drawing function for outline with path gradients
+	 * will not match and that's the line width is too small usually. Because of
+	 * this small line width we will draw a single line with the end color of
+	 * the path gradient.
+	 */
+	if(type==XFDASHBOARD_GRADIENT_TYPE_PATH_GRADIENT)
+	{
+		guint						lastIndex;
+		ClutterColor				color;
+
+		/* Get last index */
+		lastIndex=xfdashboard_gradient_color_get_number_stops(priv->color);
+
+		/* Set color from last color stop */
+		xfdashboard_gradient_color_get_stop(priv->color, lastIndex-1, NULL, &color);
+		pattern=cairo_pattern_create_rgba(CLAMP(color.red / 255.0, 0.0, 1.0),
+											CLAMP(color.green / 255.0, 0.0, 1.0),
+											CLAMP(color.blue / 255.0, 0.0, 1.0),
+											CLAMP(color.alpha / 255.0, 0.0, 1.0));
+	}
+
+	/* Return created pattern */
+	return(pattern);
+}
+
+/* Simple draw outline function which can use a cairo pattern */
+static void _xfdashboard_outline_effect_draw_outline_simple(XfdashboardOutlineEffect *self,
 															cairo_t *inContext,
 															gint inWidth,
 															gint inHeight)
 {
 	XfdashboardOutlineEffectPrivate		*priv;
+	cairo_pattern_t						*pattern;
 
 	g_return_if_fail(XFDASHBOARD_IS_OUTLINE_EFFECT(self));
 	g_return_if_fail(inWidth>0);
@@ -343,56 +526,47 @@ static void _xfdashboard_outline_effect_draw_outline_solid(XfdashboardOutlineEff
 	/* Set line width */
 	cairo_set_line_width(inContext, priv->drawLineWidth);
 
-	/* Set line color */
-	if(xfdashboard_gradient_color_get_color_type(priv->color)==XFDASHBOARD_GRADIENT_COLOR_TYPE_SOLID)
-	{
-		clutter_cairo_set_source_color(inContext, xfdashboard_gradient_color_get_solid_color(priv->color));
-	}
-		else
-		{
-			guint						lastIndex;
-			ClutterColor				color;
+	/* Create pattern for line color or gradient */
+	pattern=_xfdashboard_outline_effect_create_pattern(self, inContext, inWidth, inHeight);
 
-			/* Get last index */
-			lastIndex=xfdashboard_gradient_color_get_number_stops(priv->color);
-
-			/* Set color from last color stop */
-			xfdashboard_gradient_color_get_stop(priv->color, lastIndex-1, NULL, &color);
-			clutter_cairo_set_source_color(inContext, &color);
-		}
+	/* Set line pattern */
+	if(pattern) cairo_set_source(inContext, pattern);
 
 	/* Draw outline */
 	_xfdashboard_outline_effect_draw_outline_intern(self, inContext, inWidth, inHeight, 0.0f, FALSE);
+
+	/* Release allocated resources */
+	if(pattern) cairo_pattern_destroy(pattern);
 }
 
 /* Create texture with outline for actor */
 static CoglTexture* _xfdashboard_outline_effect_create_texture(XfdashboardOutlineEffect *self,
-																gfloat inWidth,
-																gfloat inHeight)
+																gint inWidth,
+																gint inHeight)
 {
 	XfdashboardOutlineEffectPrivate		*priv;
 	CoglContext							*coglContext;
-	CoglBitmap							*bitmapBuffer;
+	CoglBitmap							*bitmap;
 	CoglBuffer							*buffer;
 	CoglTexture							*texture;
 
 	g_return_val_if_fail(XFDASHBOARD_IS_OUTLINE_EFFECT(self), NULL);
-	g_return_val_if_fail(inWidth>=1.0f, NULL);
-	g_return_val_if_fail(inHeight>=1.0f, NULL);
+	g_return_val_if_fail(inWidth>0, NULL);
+	g_return_val_if_fail(inHeight>0, NULL);
 
 	priv=self->priv;
 	texture=NULL;
 
 	/* Set up bitmap buffer to draw outline into */
 	coglContext=clutter_backend_get_cogl_context(clutter_get_default_backend());
-	bitmapBuffer=cogl_bitmap_new_with_size(coglContext,
-											inWidth,
-											inHeight,
-											CLUTTER_CAIRO_FORMAT_ARGB32);
-	if(!bitmapBuffer) return(NULL);
+	bitmap=cogl_bitmap_new_with_size(coglContext,
+										inWidth,
+										inHeight,
+										CLUTTER_CAIRO_FORMAT_ARGB32);
+	if(!bitmap) return(NULL);
 
 	/* If buffer could be created and retrieved begin to draw */
-	buffer=COGL_BUFFER(cogl_bitmap_get_buffer(bitmapBuffer));
+	buffer=COGL_BUFFER(cogl_bitmap_get_buffer(bitmap));
 	if(buffer)
 	{
 		gpointer						bufferData;
@@ -411,7 +585,7 @@ static CoglTexture* _xfdashboard_outline_effect_create_texture(XfdashboardOutlin
 																CAIRO_FORMAT_ARGB32,
 																inWidth,
 																inHeight,
-																cogl_bitmap_get_rowstride(bitmapBuffer));
+																cogl_bitmap_get_rowstride(bitmap));
 			mappedBuffer=TRUE;
 		}
 			/* Buffer could not be mapped, so create a surface whose data we have
@@ -441,13 +615,13 @@ static CoglTexture* _xfdashboard_outline_effect_create_texture(XfdashboardOutlin
 		priv->drawRadius=MAX(priv->cornersRadius, priv->drawLineWidth);
 
 		if(priv->drawLineWidth<2 ||
-			xfdashboard_gradient_color_get_color_type(priv->color)==XFDASHBOARD_GRADIENT_COLOR_TYPE_SOLID)
+			xfdashboard_gradient_color_get_gradient_type(priv->color)!=XFDASHBOARD_GRADIENT_TYPE_PATH_GRADIENT)
 		{
-			_xfdashboard_outline_effect_draw_outline_solid(self, cairoContext, inWidth, inHeight);
+			_xfdashboard_outline_effect_draw_outline_simple(self, cairoContext, inWidth, inHeight);
 		}
 			else
 			{
-				_xfdashboard_outline_effect_draw_outline_gradient(self, cairoContext, inWidth, inHeight);
+				_xfdashboard_outline_effect_draw_outline_path_gradient(self, cairoContext, inWidth, inHeight);
 			}
 
 		cairo_destroy(cairoContext);
@@ -466,15 +640,20 @@ static CoglTexture* _xfdashboard_outline_effect_create_texture(XfdashboardOutlin
 										cairo_image_surface_get_stride(cairoSurface)*inHeight);
 			}
 
-		/* Create texture from buffer */
-		texture=cogl_texture_2d_new_from_bitmap(bitmapBuffer);
+		/* Create sliced texture from buffer as it may get very large. It would
+		 * be better to check for support of NPOT (non-power-of-two) textures
+		 * and the maximum size of a texture supported. If both (NPOT and requested
+		 * size is supported) use cogl_texture_2d_new_from_bitmap() instead of
+		 * cogl_texture_2d_sliced_new_from_bitmap().
+		 */
+		texture=cogl_texture_2d_sliced_new_from_bitmap(bitmap, COGL_TEXTURE_MAX_WASTE);
 
 		/* Destroy surface */
 		cairo_surface_destroy(cairoSurface);
 	}
 
 	/* Release allocated resources */
-	if(bitmapBuffer) cogl_object_unref(bitmapBuffer);
+	if(bitmap) cogl_object_unref(bitmap);
 
 	/* Return created texture */
 	return(texture);
@@ -498,12 +677,31 @@ static void _xfdashboard_outline_effect_paint(ClutterEffect *inEffect, ClutterEf
 	target=clutter_actor_meta_get_actor(CLUTTER_ACTOR_META(self));
 	clutter_actor_continue_paint(target);
 
-	/* Do not draw outline if this effect is not enabled */
-	if(!clutter_actor_meta_get_enabled(CLUTTER_ACTOR_META(self))) return;
-
-	/* Get and check size of outline to draw */
+	/* Get size of outline to draw */
 	clutter_actor_get_size(target, &width, &height);
 
+	/* Do not draw outline if this effect is not enabled or if width or height
+	 * is below 1 pixel as the texture will be invalid and causes trouble
+	 * (like crashes) because neither width or height (or both) must be 0 pixels.
+	 */
+	if(!clutter_actor_meta_get_enabled(CLUTTER_ACTOR_META(self)) ||
+		width<1.0f ||
+		height<1.0f)
+	{
+		return;
+	}
+
+	/* Check if size has changed. If so, destroy texture to create a new one
+	 * matching the new size.
+	 */
+	if(G_LIKELY(priv->texture))
+	{
+		if(cogl_texture_get_width(priv->texture)!=width ||
+			cogl_texture_get_height(priv->texture)!=height)
+		{
+			_xfdashboard_outline_effect_invalidate(self);
+		}
+	}
 
 	/* Create texture if no one is available */
 	if(!priv->texture)
@@ -513,15 +711,17 @@ static void _xfdashboard_outline_effect_paint(ClutterEffect *inEffect, ClutterEf
 
 		/* If we still have no texture, do nothing and return */
 		if(!priv->texture) return;
+
+		/* We only need to set texture at pipeline once after the texture
+		 * was created.
+		 */
+		cogl_pipeline_set_layer_texture(priv->pipeline,
+											0,
+											priv->texture);
 	}
 
 	/* Draw texture to stage in actor's space */
 	framebuffer=cogl_get_draw_framebuffer();
-
-	cogl_pipeline_set_layer_texture(priv->pipeline,
-										0,
-										priv->texture);
-
 	cogl_framebuffer_draw_textured_rectangle(framebuffer,
 												priv->pipeline,
 												0, 0, width, height,
@@ -815,7 +1015,7 @@ XfdashboardBorders xfdashboard_outline_effect_get_borders(XfdashboardOutlineEffe
 	return(self->priv->borders);
 }
 
-void xfdashboard_outline_effect_set_borders(XfdashboardOutlineEffect *self, XfdashboardBorders inBorders)
+void xfdashboard_outline_effect_set_borders(XfdashboardOutlineEffect *self, const XfdashboardBorders inBorders)
 {
 	XfdashboardOutlineEffectPrivate	*priv;
 
@@ -846,7 +1046,7 @@ XfdashboardCorners xfdashboard_outline_effect_get_corners(XfdashboardOutlineEffe
 	return(self->priv->corners);
 }
 
-void xfdashboard_outline_effect_set_corners(XfdashboardOutlineEffect *self, XfdashboardCorners inCorners)
+void xfdashboard_outline_effect_set_corners(XfdashboardOutlineEffect *self, const XfdashboardCorners inCorners)
 {
 	XfdashboardOutlineEffectPrivate	*priv;
 
