@@ -45,7 +45,7 @@
 #include <glib/gi18n-lib.h>
 
 #include <libxfdashboard/plugin.h>
-#include <libxfdashboard/application.h>
+#include <libxfdashboard/core.h>
 #include <libxfdashboard/settings.h>
 #include <libxfdashboard/compat.h>
 #include <libxfdashboard/debug.h>
@@ -58,8 +58,8 @@ struct _XfdashboardPluginsManagerPrivate
 	gboolean				isInited;
 	GList					*plugins;
 
-	XfdashboardApplication	*application;
-	guint					applicationInitializedSignalID;
+	XfdashboardCore			*core;
+	guint					coreInitializedSignalID;
 
 	XfdashboardSettings		*settings;
 	guint					settingsEnabledPluginsNotifySignalID;
@@ -71,9 +71,6 @@ G_DEFINE_TYPE_WITH_PRIVATE(XfdashboardPluginsManager,
 
 /* IMPLEMENTATION: Private variables and methods */
 
-/* Single instance of plugin manager */
-static XfdashboardPluginsManager*			_xfdashboard_plugins_manager=NULL;
-
 /* Find path to plugin */
 static gchar* _xfdashboard_plugins_manager_find_plugin_path(XfdashboardPluginsManager *self,
 															const gchar *inPluginName)
@@ -404,7 +401,7 @@ static void _xfdashboard_plugins_manager_on_application_initialized(XfdashboardP
 	XfdashboardPlugin					*plugin;
 
 	g_return_if_fail(XFDASHBOARD_IS_PLUGINS_MANAGER(self));
-	g_return_if_fail(XFDASHBOARD_IS_APPLICATION(inUserData));
+	g_return_if_fail(XFDASHBOARD_IS_CORE(inUserData));
 
 	priv=self->priv;
 
@@ -429,40 +426,20 @@ static void _xfdashboard_plugins_manager_on_application_initialized(XfdashboardP
 	}
 
 	/* Disconnect signal handler as this signal is emitted only once */
-	if(priv->application)
+	if(priv->core)
 	{
-		if(priv->applicationInitializedSignalID)
+		if(priv->coreInitializedSignalID)
 		{
-			g_signal_handler_disconnect(priv->application, priv->applicationInitializedSignalID);
-			priv->applicationInitializedSignalID=0;
+			g_signal_handler_disconnect(priv->core, priv->coreInitializedSignalID);
+			priv->coreInitializedSignalID=0;
 		}
 
-		priv->application=NULL;
+		priv->core=NULL;
 	}
 }
 
 /* IMPLEMENTATION: GObject */
 
-/* Construct this object */
-static GObject* _xfdashboard_plugins_manager_constructor(GType inType,
-															guint inNumberConstructParams,
-															GObjectConstructParam *inConstructParams)
-{
-	GObject									*object;
-
-	if(!_xfdashboard_plugins_manager)
-	{
-		object=G_OBJECT_CLASS(xfdashboard_plugins_manager_parent_class)->constructor(inType, inNumberConstructParams, inConstructParams);
-		_xfdashboard_plugins_manager=XFDASHBOARD_PLUGINS_MANAGER(object);
-	}
-		else
-		{
-			object=g_object_ref(G_OBJECT(_xfdashboard_plugins_manager));
-		}
-
-	return(object);
-}
-
 /* Dispose this object */
 static void _xfdashboard_plugins_manager_dispose(GObject *inObject)
 {
@@ -499,15 +476,15 @@ static void _xfdashboard_plugins_manager_dispose(GObject *inObject)
 		priv->plugins=NULL;
 	}
 
-	if(priv->application)
+	if(priv->core)
 	{
-		if(priv->applicationInitializedSignalID)
+		if(priv->coreInitializedSignalID)
 		{
-			g_signal_handler_disconnect(priv->application, priv->applicationInitializedSignalID);
-			priv->applicationInitializedSignalID=0;
+			g_signal_handler_disconnect(priv->core, priv->coreInitializedSignalID);
+			priv->coreInitializedSignalID=0;
 		}
 
-		priv->application=NULL;
+		priv->core=NULL;
 	}
 
 	if(priv->settings)
@@ -526,19 +503,6 @@ static void _xfdashboard_plugins_manager_dispose(GObject *inObject)
 	G_OBJECT_CLASS(xfdashboard_plugins_manager_parent_class)->dispose(inObject);
 }
 
-/* Finalize this object */
-static void _xfdashboard_plugins_manager_finalize(GObject *inObject)
-{
-	/* Release allocated resources finally, e.g. unset singleton */
-	if(G_LIKELY(G_OBJECT(_xfdashboard_plugins_manager)==inObject))
-	{
-		_xfdashboard_plugins_manager=NULL;
-	}
-
-	/* Call parent's class dispose method */
-	G_OBJECT_CLASS(xfdashboard_plugins_manager_parent_class)->finalize(inObject);
-}
-
 /* Class initialization
  * Override functions in parent classes and define properties
  * and signals
@@ -548,9 +512,7 @@ static void xfdashboard_plugins_manager_class_init(XfdashboardPluginsManagerClas
 	GObjectClass		*gobjectClass=G_OBJECT_CLASS(klass);
 
 	/* Override functions */
-	gobjectClass->constructor=_xfdashboard_plugins_manager_constructor;
 	gobjectClass->dispose=_xfdashboard_plugins_manager_dispose;
-	gobjectClass->finalize=_xfdashboard_plugins_manager_finalize;
 }
 
 /* Object initialization
@@ -565,8 +527,7 @@ static void xfdashboard_plugins_manager_init(XfdashboardPluginsManager *self)
 	/* Set default values */
 	priv->isInited=FALSE;
 	priv->plugins=NULL;
-	priv->application=xfdashboard_application_get_default();
-	priv->settings=g_object_ref(xfdashboard_application_get_settings(NULL));
+	priv->settings=g_object_ref(xfdashboard_core_get_settings(NULL));
 
 	/* Connect signal to get notified about changes of enabled-plugins
 	 * property in settings.
@@ -580,8 +541,9 @@ static void xfdashboard_plugins_manager_init(XfdashboardPluginsManager *self)
 	/* Connect signal to get notified when application is fully initialized
 	 * to enable loaded plugins.
 	 */
-	priv->applicationInitializedSignalID=
-		g_signal_connect_swapped(priv->application,
+	priv->core=xfdashboard_core_get_default();
+	priv->coreInitializedSignalID=
+		g_signal_connect_swapped(priv->core,
 									"initialized",
 									G_CALLBACK(_xfdashboard_plugins_manager_on_application_initialized),
 									self);
@@ -589,22 +551,6 @@ static void xfdashboard_plugins_manager_init(XfdashboardPluginsManager *self)
 
 /* IMPLEMENTATION: Public API */
 
-/**
- * xfdashboard_plugins_manager_get_default:
- *
- * Retrieves the singleton instance of #XfdashboardPluginsManager.
- *
- * Return value: (transfer full): The instance of #XfdashboardPluginsManager.
- *   Use g_object_unref() when done.
- */
-XfdashboardPluginsManager* xfdashboard_plugins_manager_get_default(void)
-{
-	GObject									*singleton;
-
-	singleton=g_object_new(XFDASHBOARD_TYPE_PLUGINS_MANAGER, NULL);
-	return(XFDASHBOARD_PLUGINS_MANAGER(singleton));
-}
-
 /**
  * xfdashboard_plugins_manager_setup:
  * @self: A #XfdashboardPluginsManager
