@@ -36,6 +36,7 @@
 #include <libxfdashboard/stylable.h>
 #include <libxfdashboard/focusable.h>
 #include <libxfdashboard/focus-manager.h>
+#include <libxfdashboard/core.h>
 #include <libxfdashboard/compat.h>
 
 
@@ -237,7 +238,7 @@ static void _xfdashboard_text_box_key_focus_in(ClutterActor *inActor)
 	clutter_stage_set_key_focus(stage, priv->actorTextBox);
 
 	/* Update focus in focus manager */
-	focusManager=xfdashboard_focus_manager_get_default();
+	focusManager=xfdashboard_core_get_focus_manager(NULL);
 	xfdashboard_focus_manager_set_focus(focusManager, XFDASHBOARD_FOCUSABLE(self));
 	g_object_unref(focusManager);
 }
