@@ -2,7 +2,7 @@
  * application: Single-instance managing application and single-instance
  *              objects like window manager and so on.
  * 
- * Copyright 2012-2016 Stephan Haller <nomad@froevel.de>
+ * Copyright 2012-2020 Stephan Haller <nomad@froevel.de>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,14 +22,16 @@
  * 
  */
 
-#ifndef __XFDASHBOARD_APPLICATION__
-#define __XFDASHBOARD_APPLICATION__
+#ifndef __LIBXFDASHBOARD_APPLICATION__
+#define __LIBXFDASHBOARD_APPLICATION__
+
+#if !defined(__LIBXFDASHBOARD_H_INSIDE__) && !defined(LIBXFDASHBOARD_COMPILATION)
+#error "Only <libxfdashboard/libxfdashboard.h> can be included directly."
+#endif
 
 #include <gio/gio.h>
-#include <xfconf/xfconf.h>
 
-#include "theme.h"
-#include "focusable.h"
+#include <libxfdashboard/focusable.h>
 
 G_BEGIN_DECLS
 
@@ -64,8 +66,15 @@ typedef struct _XfdashboardApplication				XfdashboardApplication;
 typedef struct _XfdashboardApplicationClass			XfdashboardApplicationClass;
 typedef struct _XfdashboardApplicationPrivate		XfdashboardApplicationPrivate;
 
+/**
+ * XfdashboardApplication:
+ *
+ * The #XfdashboardApplication structure contains only private data and
+ * should be accessed using the provided API
+ */
 struct _XfdashboardApplication
 {
+	/*< private >*/
 	/* Parent instance */
 	GApplication					parent_instance;
 
@@ -73,6 +82,19 @@ struct _XfdashboardApplication
 	XfdashboardApplicationPrivate	*priv;
 };
 
+/**
+ * XfdashboardApplicationClass:
+ * @initialized: Class handler for the #XfdashboardApplicationClass::initialized signal
+ * @suspend: Class handler for the #XfdashboardApplicationClass::suspend signal
+ * @resume: Class handler for the #XfdashboardApplicationClass::resume signal
+ * @quit: Class handler for the #XfdashboardApplicationClass::quit signal
+ * @shutdown_final: Class handler for the #XfdashboardApplicationClass::shutdown_final signal
+ * @theme_changed: Class handler for the #XfdashboardApplicationClass::theme_changed signal
+ * @application_launched: Class handler for the #XfdashboardApplicationClass::application_launched signal
+ * @exit: Class handler for the #XfdashboardApplicationClass::exit signal
+ *
+ * The #XfdashboardApplicationClass structure contains only private data
+ */
 struct _XfdashboardApplicationClass
 {
 	/*< private >*/
@@ -80,17 +102,6 @@ struct _XfdashboardApplicationClass
 	GApplicationClass				parent_class;
 
 	/*< public >*/
-	/* Virtual functions */
-	void (*suspend)(XfdashboardApplication *self);
-	void (*resume)(XfdashboardApplication *self);
-
-	void (*quit)(XfdashboardApplication *self);
-	void (*shutdown_final)(XfdashboardApplication *self);
-
-	void (*theme_changed)(XfdashboardApplication *self, XfdashboardTheme *inTheme);
-
-	void (*application_launched)(XfdashboardApplication *self, GAppInfo *inAppInfo);
-
 	/* Binding actions */
 	gboolean (*exit)(XfdashboardApplication *self,
 						XfdashboardFocusable *inSource,
@@ -102,19 +113,12 @@ struct _XfdashboardApplicationClass
 /* Public API */
 GType xfdashboard_application_get_type(void) G_GNUC_CONST;
 
-XfdashboardApplication* xfdashboard_application_get_default(void);
+XfdashboardApplication* xfdashboard_application_new(void);
 
 gboolean xfdashboard_application_is_daemonized(XfdashboardApplication *self);
-gboolean xfdashboard_application_is_suspended(XfdashboardApplication *self);
 
-gboolean xfdashboard_application_is_quitting(XfdashboardApplication *self);
-void xfdashboard_application_quit(void);
-void xfdashboard_application_quit_forced(void);
-
-XfconfChannel* xfdashboard_application_get_xfconf_channel(void);
-
-XfdashboardTheme* xfdashboard_application_get_theme(void);
+void xfdashboard_application_quit_forced(XfdashboardApplication *self);
 
 G_END_DECLS
 
-#endif	/* __XFDASHBOARD_APPLICATION__ */
+#endif	/* __LIBXFDASHBOARD_APPLICATION__ */
